use SOAP::Lite;
use Date::Format;
$proxy = "https://aws.demo.ascio.com/v3/AscioService.svc";
$namespace = "http://www.ascio.com/2007/01";
$soap = SOAP::Lite
    ->on_action( sub { "CreateOrder" } )
    ->proxy($proxy)
    ->ns("http://www.ascio.com/2013/02", "v3")
    ->ns("http://www.ascio.com/2013/02/AscioService", "service");
    
# Please enter your ascio-credentials here

my $header = SOAP::Header->new(
            name =>"v3:SecurityHeaderDetails",
            value => {"v3:Account" => "username", "v3:Password" =>"password"} 
        );
$soap->autotype(0);
$method = SOAP::Data->name("service:CreateOrder")->attr({xmlns => $namespace});


#Registrant
$owner =  \SOAP::Data->value(
	SOAP::Data->name('v3:FirstName','John'),
	SOAP::Data->name('v3:LastName','Doe'),
	SOAP::Data->name('v3:Address1','Address1Test'),
	SOAP::Data->name('v3:City','CityTest'),
	SOAP::Data->name('v3:PostalCode','888349'),
	SOAP::Data->name('v3:CountryCode','DK'),
	SOAP::Data->name('v3:Email',"administrator@ascio-test-domain.com")
);


#Contact
$reseller =  \SOAP::Data->value(
	SOAP::Data->name('v3:FirstName','John'),
	SOAP::Data->name('v3:LastName','Doe'),
	SOAP::Data->name('v3:OrgName','Ascio'),
	SOAP::Data->name('v3:Address1','Address1Test'),
	SOAP::Data->name('v3:City','CityTest'),
	SOAP::Data->name('v3:State','StateTest'),
	SOAP::Data->name('v3:PostalCode','888349'),
	SOAP::Data->name('v3:CountryCode','DK'),
	SOAP::Data->name('v3:Email',"administrator@ascio-test-domain.com"),
	SOAP::Data->name('v3:Type','owner')
);


#KeyValue
$keyValue =  \SOAP::Data->value(
	SOAP::Data->name('v3:Key','Title'),
	SOAP::Data->name('v3:Value','Mr.')
);


#Extensions
$markExtensions =  \SOAP::Data->value(
);


#TreatyOrStatuteMark
$mark =  \SOAP::Data->value(
	SOAP::Data->name('v3:Handle','JD123'),
	SOAP::Data->name('v3:MarkName','MarkNameTest'),
	SOAP::Data->name('v3:MarkId','MarkIdTest'),
	SOAP::Data->name('v3:AuthInfo','X4FF!zu'),
	SOAP::Data->name('v3:ServiceType','Standard'),
	SOAP::Data->name('v3:GoodsAndServicesDescription','GoodsAndServicesDescriptionTest'),
	SOAP::Data->name('v3:Labels',SOAP::Data->value(SOAP::Data->name('string',''))),
	SOAP::Data->name('v3:ClaimEmailNotification1','ClaimEmailNotification1Test'),
	SOAP::Data->name('v3:ClaimEmailNotification2','ClaimEmailNotification2Test'),
	SOAP::Data->name('v3:ClaimEmailNotification3','ClaimEmailNotification3Test'),
	SOAP::Data->name('v3:ClaimEmailNotification4','ClaimEmailNotification4Test'),
	SOAP::Data->name('v3:ClaimEmailNotification5','ClaimEmailNotification5Test'),
	SOAP::Data->name('v3:NotificationFrequency','Daily'),
	SOAP::Data->name('v3:Owner',$owner),
	SOAP::Data->name('v3:Reseller',$reseller),
	SOAP::Data->name('v3:Extensions',$markExtensions),
	SOAP::Data->name('v3:ObjectComment','Example Object Comment'),
	SOAP::Data->name('v3:Title','TitleTest'),
	SOAP::Data->name('v3:ReferenceNumber','ReferenceNumberTest'),
	SOAP::Data->name('v3:Country','DK'),
	SOAP::Data->name('v3:Region','RegionTest'),
	SOAP::Data->name('v3:ProtectionDate',new \DateTime()),
	SOAP::Data->name('v3:ExecutionDate',new \DateTime())
);


#MarkOrderDocument
$markOrderDocument =  \SOAP::Data->value(
	SOAP::Data->name('v3:FileName','anything.jpg'),
	SOAP::Data->name('v3:Content',base64_encode(123)),
	SOAP::Data->name('v3:DocType','TrademarkAssigneeDeclaration')
);


#ArrayOfMarkOrderDocument
$documents =  \SOAP::Data->value(
);


#MarkOrderRequest
$request =  \SOAP::Data->value(
	SOAP::Data->name('v3:Type','Register'),
	SOAP::Data->name('v3:Period',1),
	SOAP::Data->name('v3:TransactionComment','TransactionCommentTest'),
	SOAP::Data->name('v3:Comments','CommentsTest'),
	SOAP::Data->name('v3:Documentation','DocumentationTest'),
	SOAP::Data->name('v3:Options','OptionsTest'),
	SOAP::Data->name('v3:Mark',$mark)->attr({"xsi:type" => "v3:TreatyOrStatuteMark"});,
	SOAP::Data->name('v3:Documents',$documents)
);

@query = (
	SOAP::Data->name("service:request" => $request)->attr({"xsi:type" => "v3:MarkOrderRequest"})
);
$result = $soap->call($method => @query, $header);
unless ($result->fault) {
	$response = $result->valueof("//CreateOrderResponse/CreateOrderResult");
	print "ResultCode : $response->{'ResultCode'}\r\n";
	print "Message : $response->{'ResultMessage'}\r\n";
	print "Values: ", join(", ", $result->valueof("//CreateOrderResponse/CreateOrderResult/Errors/[>0]")), "\n";
	if ($response->{"ResultCode"} == 200) {
		$order = $result->valueof("//CreateOrderResponse/order");
		print "OrderId : $order->{'OrderId'}\r\n";
	}
}
else {
	print join ", ",
	$result->faultcode,
	$result->faultstring,
	$result->faultdetail;
}